@@ -35,12 +35,13 @@ def test_challenge_base():
 
     assert response['status'] == '401'
     assert 'cookie_form' in content
+    assert '>TiddlyWeb username and password</a>' in content
 
 def test_challenge_cookie_form():
     http = httplib2.Http()
     response, content = http.request('http://our_test_domain:8001/challenge/cookie_form', method='GET')
 
-    assert response['status'] == '200'
+    assert response['status'] == '401'
     assert '<form' in content
 
 def test_challenge_not_there_in_config():
@@ -142,28 +143,6 @@ def _put_policy(bag_name, policy_dict):
             method='PUT', headers={'Content-Type': 'application/json'}, body=json)
     assert response['status'] == '204'
 
-def test_openid():
-    """
-    An incomplete test of the openid implementation.
-    This test confirms that our server will send a redirect
-    as expected, but that's about it.
-    """
-    http = httplib2.Http()
-    response, content = http.request(
-            'http://our_test_domain:8001/challenge/openid?tiddlyweb_redirect=http://www.example.com/',
-            method='GET')
-
-    assert response['status'] == '200'
-    assert 'name="openid"' in content
-
-    response, content = http.request(
-            'http://our_test_domain:8001/challenge/openid',
-            method='POST',
-            headers={'content-type': 'application/x-www-form-urlencoded'},
-            body='openid=cdent.livejournal.com&tiddlyweb_redirect=http://www.example.com/',
-            redirections=0)
-    assert response['status'] == '302'
-
 def test_single_challenge_redirect():
     """
     When there is only one challenger configured, we should
